///////////////////////////////////////////////////////////////////////////////////////
// copy the files from this folder inside your game folder
// don't forget to include textedit.wdl
// use str_cpy(temp_str, "Your text here"); and then call create_text(temp_str); 
// look at function test_particles() to see an example
///////////////////////////////////////////////////////////////////////////////////////

bmap system_font = <system.pcx>; // not your regular font definition!
bmap flare_pcx = <flare.pcx>;

///////////////////////////////////////////////////////////////////////////////////////

string temp_str; // just a temporary string that holds your text

///////////////////////////////////////////////////////////////////////////////////////

function create_text(my_string);
function keep_particles();
function particle_text();

///////////////////////////////////////////////////////////////////////////////////////

function create_text(my_string)
{
	var number_of_chars; // number of characters in our string
	var format; // returned by bmap_lock, gives the type of the texture
	var char_minx; // minimum x for the current char on the bitmap
	var char_miny; // minimum y for the current char on the bitmap
	var char_maxx; // maximum x for the current char on the bitmap
	var char_maxy; // maximum y for the current char on the bitmap
	var pixel_value; // stores the RGB value of the current pixel that is being read from the font bitmap
	var char_width; // width of a character from system_font
	var char_height; // height of a character from system_font
	var particle_width = 1.3; // sets the width of the letters, play with this value 
	var particle_height = 1.5; // sets the height of the letters, play with this value
	var particle_space = 12; // space between the letters, play with this value

	char_width = bmap_width(system_font) / 32; // each system_font row has 32 chars
	char_height = bmap_height(system_font) / 4; // system_font bitmap has 4 rows
	number_of_chars = str_len(my_string); // get the number of chars from my_string aka temp_str in my test_particles() function
	format = bmap_lock(system_font, 0); // lock the font bitmap and get its texture format

	while (number_of_chars > 0) // create the particles char by char
	{
		temp = str_to_asc(my_string); // changes the first char in temp_str to ascii (a figure)
		str_clip (my_string, 1); // removes the first character from my_string in order to move on to the 2nd char and so on
		char_minx = (temp % 32) * char_width; // // get the minimum x position for the curent char too
		char_miny = int(temp / 32) * char_height; // get the minimum y position on the font bitmap for the curent char
		char_maxx = char_minx + char_width; // compute the maximum x position
		char_maxy = char_miny + char_height; // and the maximum y position on the font bitmap for the current char

		while(char_minx < char_maxx) // loop until you reach char_maxx
		{
			char_miny = char_maxy - char_height; // reset char_miny
			while(char_miny < char_maxy) // loop until you reach the top of the current column aka char_maxy
			{
				// read the current pixel and store its value (in pixel_value) and alpha (in temp); we won't need the alpha at all
				pixel_to_vec(pixel_value, temp, format, (pixel_for_bmap(system_font, char_minx, char_miny)));
				if (pixel_value > 0) // not a black pixel (RGB > 0)? Then let's display it!
				{
					// set the approximate position of the text in the 3D world (depends on particle_width and particle_height too)
					vec_set (temp, vector (534, 240, 40)); 
					// simply replace temp.y with temp.x to change the orientation of the text
					temp.y += (char_maxx - char_minx) * particle_width + number_of_chars * particle_space; // compute the y of the particle
					temp.z += (char_maxy - char_miny) * particle_height; // and its z
					effect(particle_text, 1, temp, nullvector); // now create the particles at the xyz position given by temp
				}
				char_miny += 1; // draw a full particle column; add 1 pixel to the y axis on the bitmap
			}
			char_minx += 1; // now move on for 1 pixel on the x axis (to the next column on the bitmap)
		}
		number_of_chars -= 1; // all the particles for the current char are generated here, so move on to the next character in the string
	}
	bmap_unlock(system_font); // now unlock the font bitmap
}

function particle_text()
{
	my.bmap = flare_pcx;
	my.flare = on;
	my.bright = on;	
	my.size = 2; // change the size of the text "pixel" here, play with this value
	my.red = 255; // and the color of the text
	my.green = 100; // using the red, green, blue values
	my.blue = 100;
	my.function = keep_particles; 
}

function keep_particles() // keeps the particles alive
{
	my.lifespan = 100;
}

function test_particles()
{
	str_cpy (temp_str, "<- Uscita Exit");
	create_text(temp_str);
}

on_t = test_particles;